@@ -1,6 +1,5 @@
 """
-GUISCRCPY by srevinsaju
-Get it on : https://github.com/srevinsaju/guiscrcpy
+guiscrcpy
 Licensed under GNU Public License
 
 This program is free software: you can redistribute it and/or modify
@@ -36,28 +35,25 @@ class InterfaceConfig:
         self.cfgpath = self.os.cfgpath()
         self.paths = self.os.paths()
         self.config = {
-            'paths': self.paths,
-            'scrcpy': None,
-            'adb': None,
-            'panels': {
-                'swipe': True,
-                'bottom': True,
-                'toolkit': True
-            },
-            'mapper': '',
-            'sha_shift': 5,
-            'scrcpy-server': None,
-            'dimension': None,
-            'swtouches': False,
-            'bitrate': 8000,
-            'fullscreen': False,
-            'dispRO': False,
-            'extra': "",
-            'cmx': "",
-            'device': {},
-            'theme': 'Breeze'
+            "version": 1,
+            "paths": self.paths,
+            "scrcpy": None,
+            "adb": None,
+            "panels": {"swipe": True, "bottom": True, "toolkit": True},
+            "mapper": "",
+            "sha_shift": 5,
+            "scrcpy-server": None,
+            "dimension": None,
+            "swtouches": False,
+            "bitrate": 8000,
+            "fullscreen": False,
+            "dispRO": False,
+            "extra": "",
+            "cmx": "",
+            "device": {},
+            "theme": "Breeze",
         }
-        self.json_file = 'guiscrcpy.json'
+        self.json_file = "guiscrcpy.json"
         if load:
             self.load_config()
 
@@ -68,42 +64,41 @@ class InterfaceConfig:
     def validate(self):
         # check scrcpy and adb are not None, else replace it with original
         # values
-        if os.getenv('APPIMAGE') is not None:
+        if os.getenv("APPIMAGE") is not None:
             # no need further configuration for adb, scrcpy and scrcpy_server
-            self.config['adb'] = os.getenv('GUISCRCPY_ADB')
-            self.config['scrcpy'] = os.getenv('GUISCRCPY_SCRCPY')
+            self.config["adb"] = os.getenv("GUISCRCPY_ADB")
+            self.config["scrcpy"] = os.getenv("GUISCRCPY_SCRCPY")
             return True
-        if self.config['adb'] is None:
-            adb_path = shutil.which('adb')
-            self.config['adb'] = adb_path
+        if self.config["adb"] is None:
+            adb_path = shutil.which("adb")
+            self.config["adb"] = adb_path
         else:
-            _adb_path = self.config['adb']
+            _adb_path = self.config["adb"]
             if not os.path.exists(_adb_path):
                 raise InvalidConfigurationError(
                     "The configuration key 'adb' is "
                     "invalid. {} does not exist. "
                     "If you did not set it on purpose, "
                     "run `guiscrcpy config -r` to reset "
-                    "the configuration".format(
-                        self.config['adb'])
+                    "the configuration".format(self.config["adb"])
                 )
-        if self.config['scrcpy'] is None:
-            scrcpy_path = shutil.which('scrcpy')
-            self.config['scrcpy'] = scrcpy_path
+        if self.config["scrcpy"] is None:
+            scrcpy_path = shutil.which("scrcpy")
+            self.config["scrcpy"] = scrcpy_path
         else:
-            _scrcpy_path = self.config['scrcpy']
+            _scrcpy_path = self.config["scrcpy"]
             if not os.path.exists(_scrcpy_path):
                 raise InvalidConfigurationError(
                     "The configuration key 'scrcpy' is "
                     "invalid. {} does not exist. "
                     "If you did not set it on purpose, "
                     "run `guiscrcpy config -r` to reset "
-                    "the configuration".format(
-                        self.config['scrcpy'])
+                    "the configuration".format(self.config["scrcpy"])
                 )
-        if (self.config['scrcpy-server'] is not None) and (
-                platform.System() == "Windows"):
-            os.environ['SCRCPY_SERVER_PATH'] = self.config['scrcpy-server']
+        if (self.config["scrcpy-server"] is not None) and (
+            platform.System() == "Windows"
+        ):
+            os.environ["SCRCPY_SERVER_PATH"] = self.config["scrcpy-server"]
         return True
 
     def __setitem__(self, key, value):
@@ -117,14 +112,14 @@ class InterfaceConfig:
         return self.config
 
     def get_scrcpy(self):
-        if self.config['scrcpy'] is not None:
-            return self.config['scrcpy']
+        if self.config["scrcpy"] is not None:
+            return self.config["scrcpy"]
         else:
             return None
 
     def get_adb(self):
-        if self.config['adb'] is not None:
-            return self.config['adb']
+        if self.config["adb"] is not None:
+            return self.config["adb"]
         else:
             return None
 
@@ -132,12 +127,12 @@ class InterfaceConfig:
         return self.cfgpath
 
     def read_file(self):
-        with open(os.path.join(self.cfgpath, self.json_file), 'r') as f:
+        with open(os.path.join(self.cfgpath, self.json_file), "r") as f:
             config = json.load(f)
         self.update_config(config)
 
     def write_file(self):
-        with open(os.path.join(self.cfgpath, self.json_file), 'w') as f:
+        with open(os.path.join(self.cfgpath, self.json_file), "w") as f:
             json.dump(self.config, f, indent=4, sort_keys=True)
 
     def check_file(self):
@@ -160,6 +155,5 @@ class InterfaceConfig:
 
     def __repr__(self):
         return 'GuiscrcpyConfig({}, "{}")'.format(
-            json.dumps(self.config, indent=4),
-            self.cfgpath
+            json.dumps(self.config, indent=4), self.cfgpath
         )
