@@ -28,13 +28,13 @@ from qtpy.QtCore import QThread
 
 from pynput import keyboard
 
-from guiscrcpy.lib.check import AdbRuntimeError
+from guiscrcpy.lib.bridge.exceptions import AdbRuntimeError
 from guiscrcpy.lib.mapper.ux import MapperUI
 
 fixed_pos = [0.0, 0.0]
 final_pos = [0.0, 0.0]
 
-json_file = 'guiscrcpy.mapper.json'
+json_file = "guiscrcpy.mapper.json"
 
 
 def log(category, message):
@@ -48,32 +48,39 @@ class Mapper:
         self.app = None
         self.adb = adb
         log("mapper", "Waiting for device...")
-        self.adb.command('wait-for-any-device')
+        self.adb.command(["wait-for-any-device"])
         log("mapper", "Device connection established...")
         self.window = None
         self.guiscrcpy_mapper_json = config_path
         self.dimensions = adb.get_dimensions(device_id)
         log("mapper", "Checking device orientation")
-        try:
-            if self.check_orientation() == 1:
-                # reverse the detected dimensions.
-                # possibly the device is landscape / not the default
-                # orientation as detected by Android Window Manager
-                self.dimensions = self.dimensions[::-1]
-        except subprocess.TimeoutExpired:
-            log("mapper", "Failed to detect orientation. fallback portait")
+        if self.check_orientation() == 1:
+            # reverse the detected dimensions.
+            # possibly the device is landscape / not the default
+            # orientation as detected by Android Window Manager
+            self.dimensions = self.dimensions[::-1]
 
     def check_orientation(self):
         proc = self.adb.shell("dumpsys input")
-        e_code = proc.wait(5)
+        try:
+            e_code = proc.wait(5)
+        except subprocess.TimeoutExpired:
+            e_code = 0
+            log(
+                "mapper",
+                "Failed to detect orientation instantly. Expect"
+                "invalid orientations.",
+            )
         if e_code != 0:
             # process failed
             raise AdbRuntimeError(
-                'adb failed with {ecode} when trying to '
-                'execute command `adb dumpsys input`'.format(ecode=e_code))
+                "adb failed with {ecode} when trying to "
+                "execute command "
+                "`adb shell dumpsys input`".format(ecode=e_code)
+            )
         out, err = proc.communicate()
         out, err = out.decode(), err.decode()
-        if 'SurfaceOrientation' in out:
+        if "SurfaceOrientation" in out:
             # SurfaceOrientation gives the idea if the device is
             # landscape or portait. SurfaceOrientation: 1 mentions that
             # the mobile is oriented in the landscape orientation
@@ -86,12 +93,12 @@ class Mapper:
                 print("Detected Landscape orientation...")
                 return 1
             else:
-                print("Failed to detect orientation from device. "
-                      "Fallback to 0")
+                print("Failed to detect orientation from device. " "Fallback to 0")
                 return 0
         else:
-            print("Failed to detect Orientation. SurfaceOrientation"
-                  " key was not found")
+            print(
+                "Failed to detect Orientation. SurfaceOrientation" " key was not found"
+            )
             return 0
 
     def set_device_id(self, device_id):
@@ -120,33 +127,33 @@ class Mapper:
         # capture screenshot using `adb screencap`
         print("Please wait. A full definition screenshot is being captured")
 
+        # revise: is sdcard a good place to store files
         adb_screencap_process = self.adb.command(
-            'shell screencap -p /sdcard/{uid}.png'.format(
-                uid=uid
-            ),
-            device_id=self._device_id
+            ["shell", "screencap", "-p", "/sdcard/{uid}.png".format(uid=uid)],
+            device_id=self._device_id,
         )
         adb_screencap_process_ecode = adb_screencap_process.wait(500)
         if adb_screencap_process_ecode != 0:
             print("Screenshot failed. Exiting")
-            print(adb_screencap_process.stdout.read().decode('utf-8'))
+            print(adb_screencap_process.stdout.read().decode("utf-8"))
             return
         # sleep for two seconds so that the image is processed
         time.sleep(2)
 
         # pull screenshot from android using `adb pull`
         adb_pull_process = self.adb.command(
-            'pull /sdcard/{uid}.png {dest}'.format(
-                uid=uid,
-                dest=os.path.dirname(self.guiscrcpy_mapper_json)
-            ),
-            device_id=self._device_id
+            [
+                "pull",
+                f"/sdcard/{uid}.png",
+                "{dest}".format(dest=os.path.dirname(self.guiscrcpy_mapper_json)),
+            ],
+            device_id=self._device_id,
         )
         adb_pull_process_ecode = adb_pull_process.wait(500)
 
         if adb_pull_process_ecode != 0:
             print("Screenshot pull failed. Exiting")
-            print(adb_pull_process.stdout.read().decode('utf-8'))
+            print(adb_pull_process.stdout.read().decode("utf-8"))
             return
 
         # sleep for 1 second to get capture time
@@ -154,13 +161,16 @@ class Mapper:
 
         # remove data from user sdcard
         self.adb.command(
-            "shell rm /sdcard/{uid}.png".format(uid=uid),
-            device_id=self._device_id
+            ["shell", "rm", f"/sdcard/{uid}.png"], device_id=self._device_id
+        )
+        print(
+            "[LOG] Screenshot captured. Saved to {cfgpath}".format(
+                cfgpath=os.path.dirname(self.guiscrcpy_mapper_json)
+            )
+        )
+        return os.path.join(
+            os.path.dirname(self.guiscrcpy_mapper_json), "{uid}.png".format(uid=uid)
         )
-        print("[LOG] Screenshot captured. Saved to {cfgpath}".format(
-            cfgpath=os.path.dirname(self.guiscrcpy_mapper_json)))
-        return os.path.join(os.path.dirname(self.guiscrcpy_mapper_json),
-                            '{uid}.png'.format(uid=uid))
 
     # The following functions handle key events on the mapper
     def on_key_press(self, key):
@@ -169,10 +179,10 @@ class Mapper:
                 print("[KEY] Hotkey command executing")
                 position_to_tap = self.config.get(key.char)
                 c = self.adb.command(
-                    'shell input tap {} {}'.format(*position_to_tap),
-                    device_id=self.get_device_id()
+                    ["shell", "input", "tap", *[str(x) for x in position_to_tap]],
+                    device_id=self.get_device_id(),
                 )
-                print(c.stdout.read().decode('utf-8'))
+                print(c.stdout.read().decode("utf-8"))
                 print("[KEY][COMPLETE]")
 
         except AttributeError:
@@ -191,10 +201,7 @@ class Mapper:
         :return:
         :rtype:
         """
-        print(
-            "[SERVER] LISTENING VALUES:"
-            "Your keys are being listened by server. "
-        )
+        print("[SERVER] LISTENING VALUES:" "Your keys are being listened by server. ")
         try:
             with keyboard.Listener(on_press=self.on_key_press) as listener:
                 listener.join()
@@ -205,11 +212,11 @@ class Mapper:
     def read_configuration(self):
         if not os.path.exists(self.guiscrcpy_mapper_json):
             self.create_configuration()
-        with open(self.guiscrcpy_mapper_json, 'r', encoding='utf-8') as f:
+        with open(self.guiscrcpy_mapper_json, "r", encoding="utf-8") as f:
             self.config.update(json.load(f))
 
     def create_configuration(self):
-        with open(self.guiscrcpy_mapper_json, 'w') as w:
+        with open(self.guiscrcpy_mapper_json, "w") as w:
             json.dump(self.config, w)
         print("Wrote configuration file.")
 
@@ -225,7 +232,7 @@ class Mapper:
         """
         print("Setting up guiscrcpy-mapper for the first time use...")
         print("Intializing GUI window")
-        if __name__ == '__main__' or initialize_qt:
+        if __name__ == "__main__" or initialize_qt:
             print("Creating QtCore window Application instance")
             self.app = QtWidgets.QApplication([])
         self.window = MapperUI(
@@ -233,15 +240,14 @@ class Mapper:
             self.get_screenshot(),
             self.dimensions,
             fixed_pos=fixed_pos,
-            final_pos=final_pos
+            final_pos=final_pos,
         )
         self.app.processEvents()
         self.app.exec_()
 
 
 class MapperAsync(QThread):
-    def __init__(self, parent, device_id, adb, initialize=True,
-                 config_path=None):
+    def __init__(self, parent, device_id, adb, initialize=True, config_path=None):
         QThread.__init__(self, parent)
         self.parent = parent
         self.adb = adb
@@ -250,8 +256,7 @@ class MapperAsync(QThread):
         self._config_path = config_path
 
     def run(self):
-        mp = Mapper(self.device_id, adb=self.adb,
-                    config_path=self._config_path)
+        mp = Mapper(self.device_id, adb=self.adb, config_path=self._config_path)
         if self.initialize:
             mp.initialize(initialize_qt=False)
         else:
