@@ -29,11 +29,7 @@ from ..ux import Ui_ToolbarPanel
 
 
 class InterfaceToolkit(QMainWindow, Ui_ToolbarPanel):
-    def __init__(self,
-                 ux_mapper=None,
-                 parent=None,
-                 frame=False,
-                 always_on_top=True):
+    def __init__(self, ux_mapper=None, parent=None, frame=False, always_on_top=True):
         """
         Side panel toolkit for guiscrcpy main window
         :param ux_mapper:
@@ -61,9 +57,11 @@ class InterfaceToolkit(QMainWindow, Ui_ToolbarPanel):
             self.ux = UXMapper()
 
     def init(self):
-        if platform.system() != "Linux" or (shutil.which("wmctrl")
-                                            and shutil.which("xdotool")
-                                            and platform.system() == "Linux"):
+        if platform.system() != "Linux" or (
+            shutil.which("wmctrl")
+            and shutil.which("xdotool")
+            and platform.system() == "Linux"
+        ):
             self.clipD2PC.clicked.connect(self.ux.copy_devpc)
             self.clipPC2D.clicked.connect(self.ux.copy_pc2dev)
             self.fullscreenUI.clicked.connect(self.ux.fullscreen)
@@ -79,7 +77,8 @@ class InterfaceToolkit(QMainWindow, Ui_ToolbarPanel):
                     'This function is disabled because "wmctrl"'
                     ' or "xdotool" is not found on your installation.'
                     "Keyboard shortcut can be used instead"
-                    ": <b>{}</b>".format(helper))
+                    ": <b>{}</b>".format(helper)
+                )
 
         self.back.clicked.connect(self.ux.key_back)
         self.screenfreeze.clicked.connect(self.quit_window)
@@ -119,13 +118,18 @@ class InterfaceToolkit(QMainWindow, Ui_ToolbarPanel):
             # This method checks if we are the last member of the windows
             # spawned and we ourselves are not a member of ourself by
             # checking the uuid generated on creation
-            if (not instance.isHidden() and instance.name != "swipe"
-                    and instance.uid != self.uid):
+            if (
+                not instance.isHidden()
+                and instance.name != "swipe"
+                and instance.uid != self.uid
+            ):
                 self.hide()
                 break
         else:
             for instance in self.parent.child_windows:  # noqa
-                if (instance.name == "swipe"
-                        and instance.ux.get_sha() == self.ux.get_sha()):
+                if (
+                    instance.name == "swipe"
+                    and instance.ux.get_sha() == self.ux.get_sha()
+                ):
                     instance.hide()
             self.hide()
